@@ -225,6 +225,10 @@ recalculate_usage (SeahorseObject *self)
 			desc = _("Credentials");
 			break;
 		case SEAHORSE_USAGE_IDENTITY:
+		    /*
+		     * Translators: "This object is a means of storing items such as 
+		     * name, email address, etc. that make up one's digital identity.
+		     */
 			desc = _("Identity");
 			break;
 		default:
@@ -615,8 +619,6 @@ GQuark
 seahorse_object_get_id (SeahorseObject *self)
 {
 	g_return_val_if_fail (SEAHORSE_IS_OBJECT (self), 0);
-	if (!self->pv->id)
-		seahorse_object_realize (self);
 	return self->pv->id;
 }
 
